| Title: | Fuzzy & Randomized Confidence Intervals |
|---|---|
| Description: | Contains the methods proposed by Geyer and Meeden (2005)<doi:10.1214/088342305000000340> and Trigo et al. (2025) <doi:10.47749/T/UNICAMP.2025.1500297> to construct fuzzy confidence intervals. Compute and plot the fuzzy membership functions of the methods, and the expected length compared with the infimum. |
| Authors: | Carlos Henrique Trigo Nasser Felix [aut, cre], Nancy Garcia [aut], Alex Sousa [aut] |
| Maintainer: | Carlos Henrique Trigo Nasser Felix <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-19 09:46:20 UTC |
| Source: | https://github.com/cran/FRCI |
Plot for "psi" type objects.
## S3 method for class 'psi' plot(x, ..., psi2 = NULL, gamma = 0.95, xlim = NULL, ylim = NULL, type = "psi")## S3 method for class 'psi' plot(x, ..., psi2 = NULL, gamma = 0.95, xlim = NULL, ylim = NULL, type = "psi")
x |
A list containing the following information.
|
... |
generic plot parameter. |
psi2 |
Another list containing the following information.
|
gamma |
the confidence level. |
xlim |
A vector containing the upper and lower values for the theta. |
ylim |
A vector containing the values of omega to be included in the plot. |
type |
The type of the plot, by default is the menbership function, and "length" for the expected length plot. |
No return value, called for side effects
x<-psi("GM",n=10) plot(x) plot(x,type="length") x<-psi(0.5,n=10) plot(x) plot(x,type="length")x<-psi("GM",n=10) plot(x) plot(x,type="length") x<-psi(0.5,n=10) plot(x) plot(x,type="length")
Function to create "psi" type objects.
psi(method, distribution = "bernoulli", n = 1, sigma = 1)psi(method, distribution = "bernoulli", n = 1, sigma = 1)
method |
numeric value or name of the method that defines how obtain confidence intervals.
|
distribution |
name of the distribution of the sample.
|
n |
sample size. |
sigma |
standard deviation (for the case of normal distribution). |
A list containing the following information.
the membership function
distribution
n
method
sigma
the upper and lower bound function of the support of the membership function.
FELIX, Carlos Henrique Trigo Nasser, Garcia, Nancy Lopes & Sousa, Alex Rodrigo dos Santos. (2025). Uma Nova Abordagem para Construção de Intervalos de Confiança Aleatorizados (Master's thesis, Universidade Estadual de Campinas, Campinas).
GEYER, C. J.; MEEDEN, G. D. Fuzzy and randomized confidence intervals and p-values. Statistical Science, v. 20, n. 4, p. 358–366, 2005. ISSN 08834237. Disponível em: http://www.jstor.org/stable/20061193.
x<-psi("GM",n=10) x[[1]](0.3,2) x[[2]] x[[3]] x[[4]] x[[5]] x[[6]](2) x<-psi(0.5,n=10) x[[1]](0.6,8) x[[2]] x[[3]] x[[4]] x[[5]] x[[6]](8)x<-psi("GM",n=10) x[[1]](0.3,2) x[[2]] x[[3]] x[[4]] x[[5]] x[[6]](2) x<-psi(0.5,n=10) x[[1]](0.6,8) x[[2]] x[[3]] x[[4]] x[[5]] x[[6]](8)